@@ -5,16 +5,14 @@ import operator
 import os
 import shlex
 import sys
+import typing as _t
 from pathlib import Path
 from textwrap import dedent
-from typing import Callable
 
-import pip
 import pytest
 from click import BadOptionUsage, Context, FileError
 from pip._internal.req import InstallRequirement
 from pip._internal.resolution.resolvelib.requirements import SpecifierRequirement
-from pip._vendor.packaging.version import Version
 
 from piptools.scripts.compile import cli as compile_cli
 from piptools.utils import (
@@ -27,7 +25,6 @@ from piptools.utils import (
     get_cli_options,
     get_compile_command,
     get_hashes_from_ireq,
-    get_pip_version_for_python_executable,
     get_sys_path_for_python_executable,
     is_pinned_requirement,
     is_url_requirement,
@@ -299,7 +296,7 @@ def test_key_from_ireq_normalization(from_line):
     ),
 )
 def test_key_from_req_on_install_requirement(
-    from_line: Callable[[str], InstallRequirement],
+    from_line: _t.Callable[[str], InstallRequirement],
     line: str,
     expected: str,
 ) -> None:
@@ -319,7 +316,7 @@ def test_key_from_req_on_install_requirement(
     ),
 )
 def test_key_from_req_on_specifier_requirement(
-    from_line: Callable[[str], InstallRequirement],
+    from_line: _t.Callable[[str], InstallRequirement],
     line: str,
     expected: str,
 ) -> None:
@@ -640,11 +637,6 @@ def test_drop_extras(from_line, given, expected):
         assert str(ireq.markers).replace("'", '"') == expected.replace("'", '"')
 
 
-def test_get_pip_version_for_python_executable():
-    result = get_pip_version_for_python_executable(sys.executable)
-    assert Version(pip.__version__) == result
-
-
 def test_get_sys_path_for_python_executable():
     result = get_sys_path_for_python_executable(sys.executable)
     assert result, "get_sys_path_for_python_executable should not return empty result"
@@ -799,14 +791,10 @@ def test_select_config_file_prefers_pip_tools_toml_over_pyproject_toml(tmpdir_cw
     pip_tools_file.touch()
 
     pyproject_file = Path("pyproject.toml")
-    pyproject_file.write_text(
-        dedent(
-            """\
+    pyproject_file.write_text(dedent("""\
             [build-system]
             requires = ["setuptools>=63", "setuptools_scm[toml]>=7"]
             build-backend = "setuptools.build_meta"
-            """
-        )
-    )
+            """))
 
     assert select_config_file(()) == pip_tools_file
